@@ -56,9 +56,9 @@ class Generator:
             dup_fields = list(set([field for field in all_fields if all_fields.count(field) > 1]))
             raise DuplicatedFields(str(dup_fields).replace("[", "").replace("]", "").replace(", ", ","))
 
-    def __process_all(self, field, type_field, function_name):
+    def __process_all(self, field, type_field, function_name, num=''):
         value = field[type_field]
-        self.__target_file.write(function_name + "(val")
+        self.__target_file.write(function_name + "(val{0}".format(num))
 
         for key, value in value.items():
             if type(value) is str:
@@ -66,6 +66,33 @@ class Generator:
             else:
                 self.__target_file.write(", " + key + "=" + str(value))
 
+    def __process_all_object(self, field, i):
+        value = field['my_object']
+        self.__target_file.write('check_format_object(val{0}, {1}'.format('' if i == 0 else i - 1, '{'))
+
+        for field in value:
+            name = field['name']
+
+            if 'my_object' in field:
+                self.__target_file.write("'" + name + "': (lambda val{0}: ".format(i))
+                self.__process_all_object(field, i + 1)
+
+            else:
+                self.__target_file.write("'" + name + "': (lambda val{0}: ".format(i))
+
+                if 'string' in field:
+                    self.__process_all(field, 'string', 'check_format_string', i)
+                elif 'number' in field:
+                    self.__process_all(field, 'number', 'check_format_number', i)
+                elif 'boolean' in field:
+                    self.__process_all(field, 'boolean', 'check_format_boolean', i)
+                elif 'date' in field:
+                    self.__process_all(field, 'date', 'check_format_date', i)
+
+            self.__target_file.write(")), ")
+
+        self.__target_file.write("}")
+
     def __create_file(self):
         if os.path.exists(self.__target_path):
             raise FileAlreadyExists(self.__target_path)
@@ -81,16 +108,20 @@ class Generator:
         for field in self.__specification['document']:
             name = field['name']
 
-            self.__target_file.write("'" + name + "': lambda val: ")
+            if 'my_object' in field:
+                self.__target_file.write("'" + name + "': lambda val: ")
+                self.__process_all_object(field, 0)
+            else:
+                self.__target_file.write("'" + name + "': lambda val: ")
 
-            if 'string' in field:
-                self.__process_all(field, 'string', 'check_format_string')
-            elif 'number' in field:
-                self.__process_all(field, 'number', 'check_format_number')
-            elif 'boolean' in field:
-                self.__process_all(field, 'boolean', 'check_format_boolean')
-            elif 'date' in field:
-                self.__process_all(field, 'date', 'check_format_date')
+                if 'string' in field:
+                    self.__process_all(field, 'string', 'check_format_string')
+                elif 'number' in field:
+                    self.__process_all(field, 'number', 'check_format_number')
+                elif 'boolean' in field:
+                    self.__process_all(field, 'boolean', 'check_format_boolean')
+                elif 'date' in field:
+                    self.__process_all(field, 'date', 'check_format_date')
 
             self.__target_file.write("),\n                     ")
 
@@ -98,12 +129,14 @@ class Generator:
 
     def __get_mandatory_fields(self):
         self.__target_file.write("    mandatories = ")
-        self.__target_file.write(str([field['name'] for field in self.__specification['document'] if field['mandatory']]))
+        self.__target_file.write(
+            str([field['name'] for field in self.__specification['document'] if field['mandatory']]))
         self.__target_file.write("\n")
 
     def __get_optional_fields(self):
         self.__target_file.write("    optionals = ")
-        self.__target_file.write(str([field['name'] for field in self.__specification['document'] if not field['mandatory']]))
+        self.__target_file.write(
+            str([field['name'] for field in self.__specification['document'] if not field['mandatory']]))
         self.__target_file.write("\n")
 
     def __finalize_file(self):
@@ -144,7 +177,7 @@ class Generator:
 
         self.__finalize_file()
 
-        
+
 if __name__ == '__main__':
     from PythonValidGen.DataRepresentation.Document import Document
     from PythonValidGen.Verifier.Verifier import Verifier
@@ -157,7 +190,7 @@ if __name__ == '__main__':
     json_paths = os.path.join(dir_path, "..", "..", "JSON_Files")
 
     if argc < 2:
-        specification_path = os.path.join(json_paths, 'mDL_specification_prototype.json')
+        specification_path = os.path.join(json_paths, 'mDL_specification_prototype1.json')
     else:
         specification_path = argv[1]
 
@@ -172,13 +205,13 @@ if __name__ == '__main__':
         target_path = argv[3]
 
     document = Document(file=specification_path, extension="JSON")
-    specification = document.content
+    _specification = document.content
 
     schema = Document(file=schema_path, extension="JSON")
     verifier = Verifier(schema.content)
 
-    verifier.verify(specification)
-    generator = Generator(specification, target_path)
+    verifier.verify(_specification)
+    generator = Generator(_specification, target_path)
     generator.main()
 
     print("File generated")
